# AWS CodeArtifact Poetry

## SonarCloud Status

[![Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=vulnerabilities)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Bugs](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=bugs)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=code_smells)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Technical Debt](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=sqale_index)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Lines of Code](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=ncloc)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)

[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=sqale_rating)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=reliability_rating)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=security_rating)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=lucasvieirasilva_aws-codeartifact-poetry&metric=alert_status)](https://sonarcloud.io/dashboard?id=lucasvieirasilva_aws-codeartifact-poetry)

AWS CodeArtifact Poetry CLI is a CLI designed to perform Poetry login with AWS CodeArtifact Private PyPi.

## Install

`pip install aws-codeartifact-poetry`

## Documentation

- See our [Documentation](https://aws-codeartifact-poetry.readthedocs.io/)

## Contributing

- See our [Contributing Guide](CONTRIBUTING.md)

## CLI Documentation

- See our [CLI Documentation](docs/CLI.md)

## Change Log

- See our [Change Log](CHANGELOG.md)
